package com.jz.sms.channel.dmHub.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.jz.sms.channel.api.DmHubApi;
import com.jz.sms.channel.chuanglan.dto.ReportDto;
import com.jz.sms.channel.dmHub.config.DmHubConfig;
import com.jz.sms.channel.dmHub.service.DmHubService;
import com.jz.sms.channel.dto.DmhubReport;
import com.jz.sms.channel.dto.ReportDetail;
import com.jz.sms.util.HttpUtil;
import com.jz.sms.util.OkHttpUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * Dm hub系统交互业务层
 */
@Service
public class DmHubServiceImpl implements DmHubService {

    private static final Logger log = LoggerFactory.getLogger(DmHubServiceImpl.class);

    @Autowired
    RedisTemplate redisTemplate;


    @Override
    public String getToken() {
        String appid = DmHubConfig.applicationId;
        String secret = DmHubConfig.applicationKey;
        String tokenUrl = DmHubConfig.tokenUrl;
        String grantType = "client_credentials";

        Map<String, String> requestMap = new HashMap<>();
        requestMap.put("appid", appid);
        requestMap.put("secret", secret);
        requestMap.put("grant_type", grantType);
        String retStr = OkHttpUtil.get(tokenUrl, requestMap);
        JSONObject retJson = JSONObject.parseObject(retStr);
        String errorCode = retJson.getString("error_code");
        if ("0".equals(errorCode)) {
            String accessToken = retJson.getString("access_token");
            String expires = retJson.getString("expires_in");
            // TODO 存redis,过期时间=expires-600（秒）
            redisTemplate.opsForValue().set("DM_HUB_TOKEN", accessToken, Long.parseLong(expires) - 600L, TimeUnit.SECONDS);
            return accessToken;
        } else {
            return null;
        }


    }

    @Override
    public Map<String, Object> smsReport(ReportDto dto) {
        DmhubReport report = new DmhubReport();

        report.setType("sms");
        ReportDetail detail = new ReportDetail();
        detail.setAudienceId(dto.getMobile());
        detail.setBatchId(dto.getUid());
        detail.setReportDate(dto.getReportTime());
        detail.setMobile(dto.getMobile());
        detail.setChargeNum(Integer.valueOf(dto.getLength()));
        detail.setSendDate(dto.getReportTime());
        if ("DELIVRD".equals(dto.getStatus())) {
            detail.setIsReceive(true);
        } else {
            detail.setIsReceive(false);
        }
        detail.setErrMessage(dto.getStatusDesc());
        report.setReports(detail);
        log.info("短信状态回执参数：{}", JSONObject.toJSONString(report));
        String retStr = HttpUtil.sendPost(DmHubConfig.report, JSONObject.toJSONString(report));
        log.info("短信状态回执响应：{}", retStr);
        return null;
    }
}
